Action

Hook result action determining how the hook output is handled.

Usage

Action
  • block: Prevents the tool use or stops the agent.
  • warn: Adds advisory context without blocking.
  • allow: Explicitly permits the action.

Attributes

Name Description
allow Hook result action determining how the hook output is handled.
block Hook result action determining how the hook output is handled.
warn Hook result action determining how the hook output is handled.

allow

Hook result action determining how the hook output is handled.

allow="allow"

  • block: Prevents the tool use or stops the agent.
  • warn: Adds advisory context without blocking.
  • allow: Explicitly permits the action.

block

Hook result action determining how the hook output is handled.

block="block"

  • block: Prevents the tool use or stops the agent.
  • warn: Adds advisory context without blocking.
  • allow: Explicitly permits the action.

warn

Hook result action determining how the hook output is handled.

warn="warn"

  • block: Prevents the tool use or stops the agent.
  • warn: Adds advisory context without blocking.
  • allow: Explicitly permits the action.