NotificationEvent
Fires on system notifications, providing message, title, and notification type.
Usage
NotificationEvent(
_raw,
ctx,
)Parameter Attributes
_raw: dict[str, Any]ctx: HookContext
Attributes
| Name | Description |
|---|---|
| event_name | Hook lifecycle events that can trigger registered hooks. |
event_name
Hook lifecycle events that can trigger registered hooks.
event_name: Event = Event.Notification
Combinable with | to match multiple events in a single hook registration.
Examples
>>> hook(Event.Stop | Event.SubagentStop, message=“review first”, block=True)