RanCommand
Transcript-history condition: true when a Bash tool use with a matching command exists.
Usage
RanCommand(
pattern,
subagents=True,
)Parameter Attributes
pattern: strsubagents: bool = True
Transcript-history condition: true when a Bash tool use with a matching command exists.
Usage
pattern: strsubagents: bool = True