TranscriptMessage
A single message in a transcript with parsed content blocks, tool-use extraction, and text access.
Usage
TranscriptMessage()Parameter Attributes
type: strcontent: list[ContentBlock]raw: RawDict = (lambda: {})()
A single message in a transcript with parsed content blocks, tool-use extraction, and text access.
Usage
type: strcontent: list[ContentBlock]raw: RawDict = (lambda: {})()