UsedSkill
Transcript-history condition: true when a Skill tool use with a matching name exists.
Usage
UsedSkill(
name,
subagents=True,
)Parameter Attributes
name: strsubagents: bool = True
Transcript-history condition: true when a Skill tool use with a matching name exists.
Usage
name: strsubagents: bool = True