Action
Hook result action determining how the hook output is handled.
Usage
ActionAttributes
| Name | Description |
|---|---|
| allow | Hook result action determining how the hook output is handled. |
| block | Hook result action determining how the hook output is handled. |
| warn | Hook result action determining how the hook output is handled. |
allow
Hook result action determining how the hook output is handled.
allow="allow"
block
Hook result action determining how the hook output is handled.
block="block"
warn
Hook result action determining how the hook output is handled.
warn="warn"