Command
A single parsed shell command with executable, arguments, env vars, and redirects.
Usage
Command()Use Command.parse(raw) to parse a command string, or access via CommandLine.
Parameter Attributes
raw: strexecutable: strargs: tuple[str, …]env: tuple[tuple[str, str], …] = ()redirects: tuple[Redirect, …] = ()