Task
A task read from Claude Code’s native task store (~/.claude/tasks/<list-id>/<id>.json).
Usage
Task()Parameter Attributes
id: strsubject: strstatus: strdescription: str = ""owner: str | None = Noneblocked_by: tuple[str, …] = ()blocks: tuple[str, …] = ()
Attributes
| Name | Description |
|---|---|
| OPEN_STATUSES | Built-in immutable sequence. |
OPEN_STATUSES
Built-in immutable sequence.
OPEN_STATUSES: tuple[str, …] = ("pending", "in_progress")
If no argument is given, the constructor returns an empty tuple. If iterable is specified the tuple is initialized from iterable’s items.
If the argument is a tuple, the return value is the same object.